# coding: utf-8

"""
    Livoltek API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pylivoltek
from pylivoltek.models.inline_response2005 import InlineResponse2005  # noqa: E501
from pylivoltek.rest import ApiException


class TestInlineResponse2005(unittest.TestCase):
    """InlineResponse2005 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse2005(self):
        """Test InlineResponse2005"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pylivoltek.models.inline_response2005.InlineResponse2005()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
